
;------------------------------------------------------------------------
; MASTER WRITE SLOT
; BIT = CARRY
;------------------------------------------------------------------------

DS1820_WRBIT
	BCF INTCON,GIE

	; set low
	BCF DS1820_IO
	BCF DS1820_DIR

	; set time
	MOVLW SYSTICKS/1000000	; > 1
	MOVWF DS1820_HELP

DS1820_WRBIT_1
	; wait
	DECFSZ DS1820_HELP,F
	GOTO DS1820_WRBIT_1

	; set output carry dependend
	BCF DS1820_DIR
	BTFSC STATUS,CARRY
	BSF DS1820_DIR

	; set time
	MOVLW SYSTICKS/83000	; min. 60
	MOVWF DS1820_HELP

DS1820_WRBIT_2
	; wait
	DECFSZ DS1820_HELP,F
	GOTO DS1820_WRBIT_2

	; high
	BSF DS1820_DIR
	BSF INTCON,GIE

	RETURN
;------------------------------------------------------------------------
; MASTER READ SLOT
; RESULT = CARRY
;------------------------------------------------------------------------

DS1820_RDBIT
	BCF INTCON,GIE

	; set low
	BCF DS1820_IO
	BCF DS1820_DIR

	; wait short typ < 15 us
	MOVLW SYSTICKS/333000
	MOVWF DS1820_HELP

DS1820_RDBIT_1
	DECFSZ DS1820_HELP,F
	GOTO DS1820_RDBIT_1

	; set high
	BSF DS1820_DIR

	; wait short typ > 1 us
	MOVLW SYSTICKS/1000000
	MOVWF DS1820_HELP

DS1820_RDBIT_2
	DECFSZ DS1820_HELP,F
	GOTO DS1820_RDBIT_2

        ; read bit
	BCF STATUS,CARRY
	BTFSC DS1820_IO
	BSF STATUS,CARRY

	BSF INTCON,GIE

	; wait long
	MOVLW SYSTICKS/111000 ; typ > 45 us
	MOVWF DS1820_HELP
DS1820_RDBIT_3
	DECFSZ DS1820_HELP,F
	GOTO DS1820_RDBIT_3

	RETURN

;------------------------------------------------------------------------
; MASTER WRITE BYTE
; W = DATA
;------------------------------------------------------------------------

DS1820_WRITE
	; store value
	MOVWF DS1820_HELP_1

	MOVLW 8
	MOVWF DS1820_HELP_2

DS1820_WB_1
	RRF DS1820_HELP_1,F
	CALL DS1820_WRBIT

	DECFSZ DS1820_HELP_2,F
	GOTO DS1820_WB_1

	RETURN

;------------------------------------------------------------------------
; MASTER READ BYTE
; W = DATA
;------------------------------------------------------------------------

DS1820_READ
	MOVLW 8
	MOVWF DS1820_HELP_2

DS1820_RB_1
	; read
	CALL DS1820_RDBIT

	RRF DS1820_HELP_1,F

	DECFSZ DS1820_HELP_2,F
	GOTO DS1820_RB_1

        MOVF DS1820_HELP_1,W

	RETURN

;------------------------------------------------------------------------
; MASTER RESET AND CHECK PRESENCE
; DS1820,2 = 1 = present
;------------------------------------------------------------------------

DS1820_RESET
	; wait min. 480 us
	MOVLW LOW(SYSTICKS/8000)
	MOVWF DS1820_HELP
	MOVLW HIGH(SYSTICKS/8000)
	MOVWF DS1820_HELP_1

	; set low
	BCF DS1820_IO
	BCF DS1820_DIR

DS1820_RESET_1
	DECF DS1820_HELP,F
        INCFSZ DS1820_HELP,W
	GOTO DS1820_RESET_1

	DECF DS1820_HELP_1,F
        INCFSZ DS1820_HELP_1,W
	GOTO DS1820_RESET_1

	; set high
	BSF DS1820_DIR

        ; set not presence
	BCF STATUS,CARRY
        BCF DS1820,2

	; DS1820 waits max. 60 s
	MOVLW SYSTICKS/80000
	MOVWF DS1820_HELP


DS1820_RESET_2
	; wait
	BTFSS DS1820_IO
	BSF STATUS,CARRY

	DECFSZ DS1820_HELP,F
	GOTO DS1820_RESET_2

        BTFSS STATUS,CARRY
        GOTO DS1820_RESET_4
        BSF DS1820,2    ; present

DS1820_RESET_4

	; wait min. 480-60 us
	MOVLW LOW(SYSTICKS/9500)
	MOVWF DS1820_HELP
	MOVLW HIGH(SYSTICKS/9500)
	MOVWF DS1820_HELP_1

DS1820_RESET_3
	DECF DS1820_HELP,F
        INCFSZ DS1820_HELP,W
	GOTO DS1820_RESET_3

	DECF DS1820_HELP_1,F
        INCFSZ DS1820_HELP_1,W
	GOTO DS1820_RESET_3

	RETURN
